@@ -25,6 +25,8 @@ class Rethink_DBS(GeneralData):
         self.tables = {}
         self.index = {}
         self.set_defaultdb(self.dbname)
+        self.active_conn = False
+        self.done_conn = False
         r = rdb
         r.set_loop_type('asyncio')
         self.r = r
@@ -34,6 +36,7 @@ class Rethink_DBS(GeneralData):
             self.save_log(msg, level)
 
     async def async_connect(self, loop=None, *args, **kwargs):
+        self.active_conn = True
         self.session = None
         try:
             if self.default_db:
@@ -45,15 +48,11 @@ class Rethink_DBS(GeneralData):
                 dbname = self.dbname
                 dbhost = self.address[0]
                 dbport = self.address[1]
-                gprint("=" * 30)
-                bprint(
-                    f"Conectando {dbname}, {dbhost}, {dbport}, for station {self.station}"
-                )
-                gprint("=" * 30)
-                self.session = await self.r.connect(db_name=dbname,
+                self.session = await self.r.connect(db=dbname,
                                                     host=dbhost,
                                                     port=dbport,
                                                     **kwargs)
+                self.done_conn = True
                 self.logger.info(
                     f"Connected to RethinkDB with database {self.default_db}")
             else:
@@ -65,15 +64,18 @@ class Rethink_DBS(GeneralData):
             kwargs["origin_exception"] = RqlError
             msg = f'''PD_CONN, ConnectionClosed {r_error} connection....'''
             self.logger.exception(kwargs.get("origin_exception"))
+            self.active_conn = False
             raise r_error
         except (socket.error, ConnectionResetError,
                 ConnectionAbortedError) as conn_error:
             msg = f'''PD_TOA_-1 + {conn_error}, ConnectionClosed rc_enu
         connection....{{socket.error}}'''
             kwargs["origin_exception"] = msg
+            self.active_conn = False
             self.logger.exception(kwargs.get("origin_exception"))
             raise conn_error
         except Exception as ex:
+            self.active_conn = False
             self.logger.exception("Excepcion al conectar a Rethinkdb %s" % ex)
             raise ex
         return self.session
@@ -107,8 +109,8 @@ class Rethink_DBS(GeneralData):
         if dbname not in list_dbs:
             await self.create_db(dbname)
         if not dbname:
-            result = self.session.use(self.defaultdb)
-            self.set_defaultdb(self.defaultdb, first_time=True)
+            result = self.session.use(self.default_db)
+            self.set_defaultdb(self.default_db, first_time=True)
             self.logger.info("Set default db to use on session %s" % dbname)
             return result
         else:
@@ -127,8 +129,8 @@ class Rethink_DBS(GeneralData):
 
     async def create_db(self, dbname: str = None):
         try:
-            if not dbname and self.defaultdb:
-                dbname = self.defaultdb
+            if not dbname and self.default_db:
+                dbname = self.default_db
             await self.list_dbs()
             result = None
             if dbname and dbname not in self.dblist:
@@ -141,6 +143,11 @@ class Rethink_DBS(GeneralData):
         except Exception as e:
             print("An exception happen when try to create a database: %s" % e)
             self.logger.exception("Error al intentar crear Database %s" % e)
+            raise e
+        except asyncio.CancelledError as c:
+            print(f"CancelledError :: An exception happen when try to create a database: {c}")
+            raise c
+
 
     async def delete_db(self, dbname: str):
         self.logger.info("Delete database %s" % dbname)
@@ -160,7 +167,7 @@ class Rethink_DBS(GeneralData):
         if not dbname:
             dbname = self.default_db
         try:
-            await self.list_tables(self.defaultdb)
+            await self.list_tables(self.default_db)
             # print("Tables by database: %s" %self.tables)
             if dbname in self.tables.keys():
                 # print("Inside create tables")
@@ -179,6 +186,9 @@ class Rethink_DBS(GeneralData):
             self.logger.exception(
                 "Error crítico al crear tabla %s, exception" % (e))
             raise e
+        except asyncio.CancelledError as c:
+            print(f"CancelledError :: An exception happen when try to create a database: {c}")
+            raise c
 
     async def get_indexes(self, table_name: str, dbname: str = None):
         if not dbname:
@@ -223,6 +233,9 @@ class Rethink_DBS(GeneralData):
             self.logger.exception(
                 f"Index {index} can't be created {table_name}, exception {e}")
             raise e
+        except asyncio.CancelledError as c:
+            print(f"CancelledError :: An exception happen when try to create a table: {c}")
+            raise c
 
     async def delete_table(self, table_name: str, dbname: str):
         if dbname in self.dblist:
@@ -255,7 +268,7 @@ class Rethink_DBS(GeneralData):
         task = asyncio.current_task()
         task.set_name(f"save_data_{table_name}")
         try:
-            if table_name in self.tables[self.defaultdb]:
+            if table_name in self.tables[self.default_db]:
                 task_coro = self.r.db(self.defaultdb).table(table_name).insert(
                     data, durability='soft').run(self.session)
                 return await task_coro
@@ -280,14 +293,14 @@ class Rethink_DBS(GeneralData):
         return self.default_db
 
     async def update_data(self, table_name, id, conditional_data):
-        dbname = self.defaultdb
+        dbname = self.default_db
         self.logger.info("Updating data in %s" % table_name)
         if table_name in self.tables[self.default_db]:
             await self.r.db(dbname).table(table_name).get(id).update(
                 conditional_data).run(self.session)
 
     async def replace_data(self, table_name, id, conditional_data):
-        dbname = self.defaultdb
+        dbname = self.default_db
         self.logger.info("Replacing data in %s" % table_name)
         if table_name in self.tables[dbname]:
             await self.r.db(dbname).table(table_name).get(id).replace(
@@ -339,6 +352,7 @@ class Rethink_DBS(GeneralData):
         if task:
             task.set_name(f"get_data_filter_{table_name}")
         dbname = self.dbname
+        print("Reading from", dbname, table_name)
         index = filter_opt.get('index')
         if table_name in self.tables.get(self.default_db, {}):
             options = {'read_mode': 'single'}
